==> ied-2.1.1.tgz: package/lib/cmd.js <==
#!/usr/bin/env node
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _minimist = require('minimist');

var _minimist2 = _interopRequireDefault(_minimist);

var _config = require('./config');

var config = _interopRequireWildcard(_config);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

if (['development', 'test'].indexOf(process.env.NODE_ENV) !== -1) {
	require('source-map-support').install();
}

var alias = {
	h: 'help',
	v: 'version',
	S: 'save',
	D: 'save-dev',
	O: 'save-optional',
	E: 'save-exact',
	r: 'registry',
	b: 'build'
};

var string = ['registry'];

var boolean = ['help', 'version', 'save', 'save-dev', 'save-optional', 'save-exact', 'build'];

var cwd = process.cwd();
var argv = (0, _minimist2.default)(process.argv.slice(2), { alias: alias, string: string, boolean: boolean });

if (argv.registry) {
	config.registry = argv.registry;
}

var installCmd = void 0;
var shellCmd = void 0;
var runCmd = void 0;
var pingCmd = void 0;
var configCmd = void 0;
var initCmd = void 0;
var linkCmd = void 0;
var unlinkCmd = void 0;
var helpCmd = void 0;
var versionCmd = void 0;
var cacheCmd = void 0;

(function () {
	if (argv.help) {
		helpCmd = require('./help_cmd').default;
		helpCmd().subscribe();
		return;
	}

	if (argv.version) {
		versionCmd = require('./version_cmd').default;
		versionCmd().subscribe();
		return;
	}

	var _argv$_ = _slicedToArray(argv._, 1);

	var subCommand = _argv$_[0];


	switch (subCommand) {
		case 'i':
		case 'install':
			installCmd = require('./install_cmd').default;
			installCmd(cwd, argv).subscribe();
			break;
		case 'sh':
		case 'shell':
			shellCmd = require('./shell_cmd').default;
			shellCmd(cwd);
			break;
		case 'r':
		case 'run':
		case 'run-script':
			runCmd = require('./run_cmd').default;
			runCmd(cwd, argv).subscribe();
			break;
		case 't':
		case 'test':
		case 'start':
		case 'build':
		case 'stop':
			runCmd = require('./run_cmd').default;
			runCmd(cwd, _extends({}, argv, { _: ['run'].concat(argv._) })).subscribe();
			break;
		case 'ping':
			pingCmd = require('./ping_cmd').default;
			pingCmd();
			break;
		case 'conf':
		case 'config':
			configCmd = require('./config_cmd').default;
			configCmd();
			break;
		case 'init':
			initCmd = require('./init_cmd').default;
			initCmd(cwd, argv);
			break;
		case 'link':
			linkCmd = require('./link_cmd').default;
			linkCmd(cwd, argv).subscribe();
			break;
		case 'unlink':
			unlinkCmd = require('./unlink_cmd').default;
			unlinkCmd(cwd, argv).subscribe();
			break;
		case 'cache':
			cacheCmd = require('./cache_cmd').default;
			cacheCmd(cwd, argv);
			break;
		case 'version':
			versionCmd = require('./version_cmd').default;
			versionCmd().subscribe();
			break;
		default:
			helpCmd = require('./help_cmd').default;
			helpCmd().subscribe();
	}
})();

==> ied-2.3.1.tgz: package/lib/cmd.js <==
#!/usr/bin/env node
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _minimist = require('minimist');

var _minimist2 = _interopRequireDefault(_minimist);

var _config = require('./config');

var config = _interopRequireWildcard(_config);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

if (['development', 'test'].indexOf(process.env.NODE_ENV) !== -1) {
	require('source-map-support').install();
}

var alias = {
	h: 'help',
	v: 'version',
	S: 'save',
	D: 'save-dev',
	O: 'save-optional',
	r: 'registry',
	b: 'build',
	prod: 'production'
};

var string = ['registry'];

var boolean = ['help', 'version', 'save', 'save-dev', 'save-optional', 'build', 'production'];

var cwd = process.cwd();
var argv = (0, _minimist2.default)(process.argv.slice(2), { alias: alias, string: string, boolean: boolean });

if (argv.registry) {
	config.registry = argv.registry;
}

var installCmd = void 0;
var shellCmd = void 0;
var runCmd = void 0;
var pingCmd = void 0;
var configCmd = void 0;
var initCmd = void 0;
var linkCmd = void 0;
var unlinkCmd = void 0;
var helpCmd = void 0;
var versionCmd = void 0;
var cacheCmd = void 0;

(function () {
	if (argv.help) {
		helpCmd = require('./help_cmd').default;
		helpCmd().subscribe();
		return;
	}

	if (argv.version) {
		versionCmd = require('./version_cmd').default;
		versionCmd().subscribe();
		return;
	}

	var _argv$_ = _slicedToArray(argv._, 1);

	var subCommand = _argv$_[0];


	switch (subCommand) {
		case 'i':
		case 'install':
			installCmd = require('./install_cmd').default;
			installCmd(cwd, argv).subscribe();
			break;
		case 'sh':
		case 'shell':
			shellCmd = require('./shell_cmd').default;
			shellCmd(cwd).subscribe();
			break;
		case 'r':
		case 'run':
		case 'run-script':
			runCmd = require('./run_cmd').default;
			runCmd(cwd, argv).subscribe();
			break;
		case 't':
		case 'test':
		case 'start':
		case 'build':
		case 'stop':
			runCmd = require('./run_cmd').default;
			runCmd(cwd, _extends({}, argv, { _: ['run'].concat(argv._) })).subscribe();
			break;
		case 'ping':
			pingCmd = require('./ping_cmd').default;
			pingCmd();
			break;
		case 'conf':
		case 'config':
			configCmd = require('./config_cmd').default;
			configCmd();
			break;
		case 'init':
			initCmd = require('./init_cmd').default;
			initCmd(cwd, argv);
			break;
		case 'link':
			linkCmd = require('./link_cmd').default;
			linkCmd(cwd, argv).subscribe();
			break;
		case 'unlink':
			unlinkCmd = require('./unlink_cmd').default;
			unlinkCmd(cwd, argv).subscribe();
			break;
		case 'cache':
			cacheCmd = require('./cache_cmd').default;
			cacheCmd(cwd, argv);
			break;
		case 'version':
			versionCmd = require('./version_cmd').default;
			versionCmd().subscribe();
			break;
		default:
			helpCmd = require('./help_cmd').default;
			helpCmd().subscribe();
	}
})();
